==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/StateActionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.StateActionBody;
import io.ciera.tool.sql.ooaofooa.body.StateActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;

import java.util.Arrays;
import java.util.List;


public class StateActionBodySetImpl extends InstanceSet<StateActionBodySet,StateActionBody> implements StateActionBodySet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setAct_ID( ref_Act_ID );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public ActionSet R691_specifies_processing_for_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( StateActionBody stateactionbody : this ) actionset.add( stateactionbody.R691_specifies_processing_for_Action() );
        return actionset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( StateActionBody stateactionbody : this ) bodyset.add( stateactionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public StateActionBody nullElement() {
        return StateActionBodyImpl.EMPTY_STATEACTIONBODY;
    }

    @Override
    public StateActionBodySet emptySet() {
      return new StateActionBodySetImpl();
    }

    @Override
    public StateActionBodySet value() {
        return this;
    }

    @Override
    public List<StateActionBody> elements() {
        return Arrays.asList(toArray(new StateActionBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/StateActionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.StateActionBody;
import io.ciera.tool.sql.ooaofooa.body.StateActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StateActionBodySetImpl extends InstanceSet<StateActionBodySet,StateActionBody> implements StateActionBodySet {

    public StateActionBodySetImpl() {
    }

    public StateActionBodySetImpl(Comparator<? super StateActionBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( StateActionBody stateactionbody : this ) stateactionbody.setAct_ID( ref_Act_ID );
    }


    // selections
    @Override
    public ActionSet R691_specifies_processing_for_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( StateActionBody stateactionbody : this ) actionset.add( stateactionbody.R691_specifies_processing_for_Action() );
        return actionset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( StateActionBody stateactionbody : this ) bodyset.add( stateactionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public StateActionBody nullElement() {
        return StateActionBodyImpl.EMPTY_STATEACTIONBODY;
    }

    @Override
    public StateActionBodySet emptySet() {
      return new StateActionBodySetImpl();
    }

    @Override
    public StateActionBodySet emptySet(Comparator<? super StateActionBody> comp) {
      return new StateActionBodySetImpl(comp);
    }

    @Override
    public StateActionBodySet value() {
        return this;
    }

    @Override
    public List<StateActionBody> elements() {
        return Arrays.asList(toArray(new StateActionBody[0]));
    }

}
